@@ -15,36 +15,31 @@ sub new {
     my @lines = split /\n|\r|\n\r/, $str;
 
     my $self = {
-		lines => \@lines,
-		tokens => [],
-		ln => 0,
-	       };
+                lines => \@lines,
+                tokens => [],
+                ln => 0,
+               };
 
     bless $self, $class;
     return $self;
 }
 
 sub _new_line {
-    my ($self) = @_;
+    my ($self, $dont_modify) = @_;
 
     my $line = '';
 
     until ($line) {
-	$line = shift @{$self->{lines}};
-	$self->{ln}++;
+        $line = shift @{$self->{lines}};
+        $self->{ln}++;
 
-	$line =~ s/^\s*(.*)$/$1/;
-	$line =~ s/^(#.*)$//;
-
-	if ($line) {
-	    push @{$self->{tokens}}, split /\s+/, $line;
-	    push @{$self->{tokens}}, ' EOL ';
-	}
-	unless (scalar @{$self->{lines}}) {
-	    push @{$self->{tokens}}, ' EOF ';
-	    return;
-	}
+        unless ( $dont_modify ) {
+            $line =~ s/^\s*(.*)$/$1/;
+            $line =~ s/^(\#.*)$//;
+        }
+        last unless (scalar @{$self->{lines}});
     }
+    return $line;
 }
 
 
